@@ -25,7 +25,8 @@ IKL <- function( params,      # parameters over which to calculate
 #  --> The center of each KL information: theta'' = (theta + theta')/2
 #  --> The half-width of the corresponding indifference region: abs(theta'' - theta)
 
-# We're calculating shifted KL information as we go from theta' - delta to theta' + delta
+# Note: 1) Shifted KL information as we go from theta' - delta to theta' + delta
+#       2) X.theta - X.delta will always/must always equal theta for all points.
 
 #~~~~~~~~~~~~~~~~#
 # KL-Information #
@@ -38,7 +39,7 @@ IKL <- function( params,      # parameters over which to calculate
 # And Integrate #
 #~~~~~~~~~~~~~~~#
 
-  info <- apply(Y, MARGIN = 1, FUN = integrate.xy, x = X)
+  info <- apply(Y, MARGIN = 2, FUN = integrate.q, x = X)
   
   return( list(item = info) )
   
